@@ -28,7 +28,7 @@
 
 /*--------------------------------------------------------------------*/
 
-static char *version = "MACVT -- Algol 60 Converter, Version 2.5";
+static char *version = "MACVT -- Algol 60 Converter, Version 2.6";
 /* Version information. */
 
 static char *infilename = "";
@@ -957,8 +957,8 @@ static void display_help(char *my_name)
 
 static void display_version(void)
 {     printf("%s\n", version);
-      printf("Copyright (C) 2000, 2001, 2002 Free Software Foundation, "
-         "Inc.\n");
+      printf("Copyright (C) 2000, 2001, 2002, 2007 Free Software Founda"
+         "tion, Inc.\n");
       printf("This program is free software; you may redistribute it un"
          "der the terms of\n");
       printf("the GNU General Public License. This program has absolute"
